@@ -1,5 +1,8 @@
+import re
+
 from django.db.models import (
     CASCADE,
+    BooleanField,
     CharField,
     ForeignKey,
     ImageField,
@@ -13,6 +16,9 @@ class Event(Model):
     description = TextField()
     image = ImageField(upload_to='event')
 
+    def __str__(self):
+        return self.title
+
 
 class Artist(Model):
     name = CharField(max_length=50)
@@ -21,24 +27,45 @@ class Artist(Model):
     telephone = CharField(max_length=13)
     picture = ImageField(upload_to='artist')
 
+    def __str__(self):
+        return self.name
+
 
 class Collection(Model):
+    event = ForeignKey(Event, on_delete=CASCADE)
     artist = ForeignKey(Artist, on_delete=CASCADE)
 
+    def __str__(self):
+        return self.artist.name
+
 
 class Product(Model):
     collection = ForeignKey(Collection, on_delete=CASCADE)
     title = CharField(max_length=50)
     description = TextField()
+    availability = BooleanField(default=True)
     picture = ImageField(upload_to='product')
 
+    @property
+    def seller(self):
+        self.collection.artist
+
+    def __str__(self):
+        return self.title
+
 
 class ProductOption(Model):
     reference = ForeignKey(Product, on_delete=CASCADE)
-    option = CharField(max_length=50),
+    key = CharField(max_length=50)
     value = CharField(max_length=50)
 
+    def __str__(self):
+        return self.key
+
 
 class ExtraPicture(Model):
     reference = ForeignKey(Product, on_delete=CASCADE)
     image = ImageField(upload_to='product')
+
+    def __str__(self):
+        return self.image.name
